Command

Struct Command 

pub struct Command { /* private fields */ }
Representation of a GTP controller to engine command.

Implementations

Source

impl Command

pub fn new(name: &str) -> Command

Constructs a new GTP controller command to be sent to the GTP engine.

use gtp;

let mut c = gtp::Command::new("list_commands");
c.args(|eb| eb.i(10).f(10.20).s("OK").list());
// send with:
let gtp_bytes = c.to_bytes();
// or if you need the string:
let gtp_str = c.to_string();
pub fn new_with_args<T>(name: &str, args: T) -> Command
where T: Fn(&mut EntityBuilder) -> &mut EntityBuilder,

Builds a new GTP engine command ready with the arguments:

use gtp;
assert_eq!(
    gtp::Command::new_with_args("boardsize", |eb| eb.i(9)).to_string(),
    "boardsize 9\n");
pub fn cmd<T>(name: &str, args: T) -> Command
where T: Fn(&mut EntityBuilder) -> &mut EntityBuilder,

Shorthand for Command::new_with_args.

pub fn set_id(&mut self, id: u32)

Sets the ID of the command.

use gtp;

let mut c = gtp::Command::new("list_commands");
c.set_id(12);
assert_eq!(c.to_string(), "12 list_commands\n");
pub fn args<T>(&mut self, f: T)
where T: Fn(&mut EntityBuilder) -> &mut EntityBuilder,

Helper function to construct Entity arguments for this Command.

use gtp;

let mut c = gtp::Command::new("list_commands");
c.args(|eb| eb.i(10).f(10.20).s("OK").list());
assert_eq!(c.to_string(), "list_commands 10 10.2 OK\n");
pub fn set_args(&mut self, args: &Entity)

Function to set Entity arguments:

use gtp;

let mut c = gtp::Command::new("list_commands");
c.set_args(&gtp::entity(|eb| eb.v((19, 19))));
pub fn to_string(&self) -> String

Generates a String representation of the GTP command.

pub fn to_bytes(&self) -> Vec<u8>

Generates a byte vector representation of the GTP command, ready to be sent to another process.